@@ -42,6 +42,9 @@ bonds_scaling = 1.0  # ratio
 min_bonds_length = 0.00  # nm
 bonds_scaling_str = ''  # constraints and bonds ids + their required target AA-mapped distributions rescaled averages
 
+# NOTE: in the benchmark of the paper we used bonds2_angles_scoring_factor = 500 and fct_guess_min_flat_diff_angles = 50,
+#       differences in the results should be small but still an improvement
+
 # building of the initial guesses for optimization, defaults
 bond_dist_guess_variation = 0.025  # nm
 angle_value_guess_variation = 10  # degrees
@@ -87,7 +90,7 @@ help_aa_tpr = 'Topology binary file of your reference AA simulation (TPR)'
 help_aa_traj = 'Trajectory file of the reference AA simulation (XTC, TRR)\nPBC are handled internally if trajectory contains box dimensions'
 help_cg_map = 'Mapping file of the atoms to CG beads (NDX-like file format)'
 help_mapping_type = 'Center Of Mass (COM) or Center Of Geometry (COG), for\ninterpreting the mapping file'
-help_verbose = 'Display more details on each processing step'
+help_verbose = 'Display more processing details & error traceback'
 help_gmx_path = 'Your Gromacs alias/path'
 help_bonds_scaling = 'Scaling factor for ALL AA-mapped bonds/constraints lengths\nOnly one of arguments -bonds_scaling, -bonds_scaling_str\nand -min_bonds_length can be provided'
 help_min_bonds_length = 'Required minimum length of a bond or constraint between 2 CG\nbeads (distributions avg in nm), used both as:\n1. Threshold to identify ALL short AA-mapped bonds/constraints\n2. Target avg to rescale ALL those bonds/constraints'
