@@ -204,7 +204,6 @@ def run(ns):
     scg.get_atoms_weights_in_beads(ns)  # get weights of atoms within beads
 
     scg.read_cg_itp_file(ns)  # load the ITP object and find out geoms grouping
-    ns.cg_itp_input = copy.deepcopy(ns.cg_itp)
     scg.process_scaling_str(ns)  # process the bonds scaling specified by user
 
     print()
@@ -279,7 +278,7 @@ def run(ns):
         ns.cg_itp['constraint'][grp_constraint]['hist'] = constraint_hist
 
         ns.domains_val['constraint'].append([round(np.min(constraint_values), 3), round(np.max(constraint_values), 3)])
-        print(f'  Constraint grp {grp_constraint+1} -- Average value: '+str(round(constraint_avg, 2))+' nm -- Initial equilibrium value: '+str(ns.cg_itp['constraint'][grp_constraint]['value'])+' nm')
+        print(f'  Constraint grp {grp_constraint+1} -- Average value: '+str(round(constraint_avg, 2))+' nm -- Initial equilibrium value: '+str(round(ns.cg_itp['constraint'][grp_constraint]['value'], 2))+' nm')
 
     # get ref atom hists + find very first distances and force constants guesses for bonds groups
     for grp_bond in range(ns.nb_bonds):
@@ -295,7 +294,7 @@ def run(ns):
         ns.data_BI['bond'].append([np.histogram(bond_values, range=(xmin, xmax), bins=config.bi_nb_bins)[0], np.std(bond_values), np.mean(bond_values), (xmin, xmax)])
 
         ns.domains_val['bond'].append([round(np.min(bond_values), 3), round(np.max(bond_values), 3)])  # boundaries of force constats during optimization
-        print(f'  Bond grp {grp_bond+1} -- Average value: '+str(round(bond_avg, 2))+' nm -- Initial equilibrium value: '+str(ns.cg_itp['bond'][grp_bond]['value'])+' nm')
+        print(f'  Bond grp {grp_bond+1} -- Average value: '+str(round(bond_avg, 2))+' nm -- Initial equilibrium value: '+str(round(ns.cg_itp['bond'][grp_bond]['value'], 2))+' nm')
 
     # get ref atom hists + find very first values and force constants guesses for angles groups
     for grp_angle in range(ns.nb_angles):
@@ -311,7 +310,7 @@ def run(ns):
         ns.data_BI['angle'].append([np.histogram(angle_values_rad, range=(np.deg2rad(xmin), np.deg2rad(xmax)), bins=config.bi_nb_bins)[0], np.std(angle_values_rad), (xmin, xmax)])
 
         ns.domains_val['angle'].append([round(np.min(angle_values_deg), 2), round(np.max(angle_values_deg), 2)])  # boundaries of force constants during optimization
-        print(f'  Angle grp {grp_angle+1} -- Average value: ' + str(round(angle_avg, 2)) + ' degrees -- Initial equilibrium value: '+str(ns.cg_itp['angle'][grp_angle]['value'])+' degrees')
+        print(f'  Angle grp {grp_angle+1} -- Average value: ' + str(round(angle_avg, 2)) + ' degrees -- Initial equilibrium value: '+str(round(ns.cg_itp['angle'][grp_angle]['value'], 2))+' degrees')
 
     # get ref atom hists + find very first values and force constants guesses for dihedrals groups
     for grp_dihedral in range(ns.nb_dihedrals):
@@ -326,7 +325,7 @@ def run(ns):
         ns.data_BI['dihedral'].append([np.histogram(dihedral_values_rad, range=(np.deg2rad(xmin), np.deg2rad(xmax)), bins=2 *config.bi_nb_bins)[0], np.std(dihedral_values_rad), np.mean(dihedral_values_rad), (xmin, xmax)])
 
         ns.domains_val['dihedral'].append([round(np.min(dihedral_values_deg), 2), round(np.max(dihedral_values_deg), 2)])  # boundaries of force constats during optimization
-        print(f'  Dihedral grp {grp_dihedral+1} -- Average value: ' + str(round(dihedral_avg, 2)) + ' degrees -- Initial equilibrium value: '+str(ns.cg_itp['dihedral'][grp_dihedral]['value'])+' degrees')
+        print(f'  Dihedral grp {grp_dihedral+1} -- Average value: ' + str(round(dihedral_avg, 2)) + ' degrees -- Initial equilibrium value: '+str(round(ns.cg_itp['dihedral'][grp_dihedral]['value'], 2))+' degrees')
 
     if not ns.bonds_rescaling_performed:
         print('  No bonds rescaling performed')
@@ -504,8 +503,8 @@ def run(ns):
           np.sqrt(ns.nb_angles * config.sim_crash_EMD_indep_score) + \
           np.sqrt(ns.nb_dihedrals * config.sim_crash_EMD_indep_score) \
           , 3)
-        # nb_particles = int(10 + 2*np.sqrt(len(search_space_boundaries))) # formula used by FST-PSO to choose nb of particles, which defines the number of initial guesses we can use
-        nb_particles = int(round(2 + np.sqrt(len(search_space_boundaries)))) # adapted to have less particles and fitted to our problems, which has good initial guesses and error driven initialization
+        # nb_particles = int(10 + 2*np.sqrt(len(search_space_boundaries)))  # formula used by FST-PSO to choose nb of particles, which defines the number of initial guesses we can use
+        nb_particles = int(round(2 + np.sqrt(len(search_space_boundaries))))  # adapted to have less particles and fitted to our problems, which has good initial guesses and error driven initialization
         # nb_particles = 2 # for tests
         initial_guess_list = scg.get_initial_guess_list(ns, nb_particles)
 
